pub trait Renderable {
// Required methods
fn render(&self, headers: bool) -> String;
fn simple_render(&self) -> String;
}Expand description
Provides the ability for an object to be rendered to the command line
Required Methods
Sourcefn render(&self, headers: bool) -> String
fn render(&self, headers: bool) -> String
Render aims to render as much detail as possible and can render to multiple lines
Sourcefn simple_render(&self) -> String
fn simple_render(&self) -> String
Simple render aims to output to a single line
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".